FullGrid: The full grid of lat and lon values expected for the netcdf

Description Usage Format Notes

Description

This dataset contains all of the combinations of the lat and lon coordinates that are expected for the netcdf.

This vector contains all of the names of the GCAM land cover types downscaled by the Demeter.

Usage

1
2
3

Format

Data frame with 2 columns

latitude

The latitdue values.

longitude

The longitude values.

Notes

Demeter only returns data that covers land but in order to convert a data frame to a netcdf we need all of the possible combinations of the lat and lon coordinates. This constains the full grid of expected lat and lon values.


kdorheim/demeterNCDF documentation built on Dec. 3, 2019, 9 p.m.