Description Usage Format Notes
This dataset contains all of the combinations of the lat and lon coordinates that are expected for the netcdf.
This vector contains all of the names of the GCAM land cover types downscaled by the Demeter.
1 2 3 |
Data frame with 2 columns
The latitdue values.
The longitude values.
Demeter only returns data that covers land but in order to convert a data frame to a netcdf we need all of the possible combinations of the lat and lon coordinates. This constains the full grid of expected lat and lon values.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.